@@ -34,4 +34,5 @@ done
 
 
 # Download swagger.json from the GitHub repository
-curl -O "https://raw.githubusercontent.com/lightdash/lightdash/${lightdash_version:?}/packages/backend/src/generated/swagger.json"
+url="https://raw.githubusercontent.com/lightdash/lightdash/${lightdash_version:?}/packages/backend/src/generated/swagger.json"
+curl "${url:?}" --output "${SCRIPT_DIR}/swagger.json"
